public class DashboardFragment extends Fragment {
	public DashboardFragment(GUIPanelComponent rootPanel) {
		super(rootPanel);
		init();
	}
	private void init() {
		GUIImageComponent.create(rootPanel, "img/storestats.png").styleName.set(Text.fromString("headingicon"));
		GUILabelComponent.create(rootPanel, "${Store statistics}").styleName.set(Text.fromString("subtitle"));
		GUIPanelComponent mainTable = GUIPanelComponent.createTable(rootPanel);
		mainTable.styleName.set(Text.fromString("mainStatsTable"));
		StatisticTableDynamicPanel totalOrdersTable = new StatisticTableDynamicPanel();
		totalOrdersTable.type.set(Integer.valueOf(1));
		TableLayoutData.setRowColumn(totalOrdersTable, 0, 0, 1, 2);
		mainTable.children.add(totalOrdersTable);
		StatisticTableDynamicPanel incompleteOrdersTable = new StatisticTableDynamicPanel();
		incompleteOrdersTable.type.set(Integer.valueOf(2));
		TableLayoutData.setRowColumn(incompleteOrdersTable, 1, 0);
		mainTable.children.add(incompleteOrdersTable);
		StatisticTableDynamicPanel registredCustomersTable = new StatisticTableDynamicPanel();
		registredCustomersTable.type.set(Integer.valueOf(3));
		TableLayoutData.setRowColumn(registredCustomersTable, 1, 1);
		mainTable.children.add(registredCustomersTable);
		StatisticTableDynamicPanel bestsellersQtyTable = new StatisticTableDynamicPanel();
		bestsellersQtyTable.type.set(Integer.valueOf(4));
		TableLayoutData.setRowColumn(bestsellersQtyTable, 2, 0);
		mainTable.children.add(bestsellersQtyTable);
		StatisticTableDynamicPanel bestsellersAmountTable = new StatisticTableDynamicPanel();
		bestsellersAmountTable.type.set(Integer.valueOf(5));
		TableLayoutData.setRowColumn(bestsellersAmountTable, 2, 1);
		mainTable.children.add(bestsellersAmountTable);
	}
	protected GUIContainerComponent getDynamicContents(IElement el) {
		GUIPanelComponent gpc = GUIPanelComponent.createTable(null);
		gpc.styleName.set(Text.fromString("fancyTable"));
		if (el == null || !(el instanceof Shop)) {
    		return gpc;
    	}
		Shop shop = (Shop) el;
		int type = this.type.val(); // which stats table
		String[][] labels = null;
		List<Product> products = null;
		switch (type) {
		case 1:
			labels = Shop.getTotalOrdersStats();
			break;
		case 2:
			labels = Shop.getIncompleteOrdersStats();
			break;
		case 3:
			labels = Shop.getRegistredCustomersStats();
			break;
		case 4:
			labels = Shop.getBestsellersByQuantity();
			products = Shop.getBestellerProductsByQuantity();
			break;
		case 5:
			labels = Shop.getBestsellersByAmount();
			products = Shop.getBestsellerProductsByAmmount();
			break;
		}
		boolean isBestsellers = type >= 4;
		generateTable(gpc, labels, products, isBestsellers);
		return gpc;
	}
	private void generateTable(GUIPanelComponent parentTable, String[][] labels, List<Product> products, boolean isBestsellersTable) {
		int row = labels.length, col = labels[0].length;
		for (int i = 0; i < row; i++) {
			for (int j = 0; i < col; j++) {
				if (isBestsellersTable && j == 0 && i > 0) {
					GUIBufferComponent productBuf = GUIBufferComponent.create(parentTable, true, products.get(i - 1));
					GUISingleElementComponent p = GUISingleElementComponent.create(parentTable, row, col);
					GUIComponentBinding.create(productBuf.output, p.element);
				} else {
					GUILabelComponent label = GUILabelComponent.create(parentTable, labels[i][j], row, col);
					if (i == 0) {
						label.styleName.set(Text.fromString("header"));
					}
				}
			}
		}
		GUIButtonComponent refreshBut = GUIButtonComponent.create(parentTable, "", row, 0);
		GUIComponentBinding.create(refreshBut.click, this.refreshContents);
	}
}